#include <iostream>

#include <vector>

#include <algorithm>

#define MAX(a,b) (a>b?a:b)
#define MIN(a,b) (a<b?a:b)

using namespace std;

int sign(float x){
	if(x>0) return 1;
	if(x<0) return -1;
	return 0;
}

class point{
	public:
	point() : x(0),y(0){};
	point(float x, float y) : x(x), y(y) {};
	float x;
	float y;
	
	point operator -(const point & src){
		return point(this->x-src.x,this->y-src.y);
	}
	
	float operator *(const point & src){
		return this->x*src.x+this->y*src.y;
	}
	bool operator < (const point & src) const {
		if (this->x<src.x)return true;
		if(this->x==src.x && this->y<src.y) return true;
		return false;
	}
};

class AABB;

class line{
	public:
		point start, end;
		line(){};
		line(point start, point end):start(start),end(end) {
			point tmp=end-start;
			this->normVec=point(-tmp.y,tmp.x);
			d=-(normVec*start);
		};
		
		point normVec;
		float d;
		
		float solve(point p) const {
			return (p*this->normVec)+this->d;
		}
		
		bool isects(const line & isect) const {
			return (
			       sign(this->solve(isect.start)) == -sign(this->solve(isect.end))
					&&
				sign(isect.solve(this->start)) == -sign(isect.solve(this->end))
			       );
		}
		
		bool operator < (const line & src) const {
			if (this->start< src.start) return true;
			if(src.start<this->start) return false;
			if(this->end<src.end) return true;
			return false;
		}
		
		bool operator == (const line & src) const {
			if (*this<src || src<*this)return false;
			return true;
		}
};

class AABB{
	public:
		AABB(point p1, point p2){
			tr.x=MAX(p1.x,p2.x);
			tr.y=MAX(p1.y,p2.y);
			lb.x=MIN(p1.x,p2.x);
			lb.y=MIN(p1.y,p2.y);
			
			corners[0]=tr;
			corners[1]=lb;
			corners[2]=point(tr.x,lb.y);
			corners[3]=point(lb.x,tr.y);
		}
		
		bool isects(const line & isect){
			int signs[4];
			for (int i=0;i<4;i++){
				signs[i]=sign(isect.solve(corners[i]));
			}
			
			bool tmp=true,tmp2=true;
			
			for (int i=0;i<4;i++){
				if(signs[i]<0)
					tmp=false;
			}

			for (int i=0;i<4;i++){
				if(signs[i]>0)
					tmp2=false;
			}
			
			if(!tmp && !tmp2){
				if (
				MAX(isect.start.y,isect.end.y)<=lb.y ||
				MAX(isect.start.x,isect.end.x)<=lb.x ||
				MIN(isect.start.y,isect.end.y)>=tr.y ||
				MIN(isect.start.x,isect.end.x)>=tr.x
				   )
				return false;
				return true;
			}
			
			return false;
		}

		
		point tr, lb;
		
		point corners[4];
};

struct point2i{
	int x,y;
};

bool isNonIntersecting(point2i p,vector<line>&lines){
	AABB box(point(p.x,p.y),point(p.x+1,p.y-1));
	
	for(vector<line>::iterator it=lines.begin();it!=lines.end();it++){
		if(box.isects(*it))
			return false;
	}
	return true;
}

int getTotalIntersections(line l, vector<line>& lines){
	int counter=0;
	for(vector<line>::iterator it=lines.begin();it!=lines.end();it++){
		if(l.isects(*it))
			counter++;
	}
	return counter;
}

int main (int argc, char * argv[]) {
	while(true){
		int numVertices;
		scanf("%d",&numVertices);
		if(numVertices==0)
			return 0;
		
		vector<line> linevec(numVertices);
		int minx=200,miny=200,maxx=-200,maxy=-200;
		bool first=true;
		point start;
		point last;
		for(int i=0;i<numVertices;i++){
			int x,y;
			scanf("%d %d", &x, &y);
			point tmp(x,y);
			if(first){
				first=false;
				start=tmp;
			}
			if(tmp.x<minx)
				minx=tmp.x;
			if(tmp.x>maxx)
				maxx=tmp.x;
			if(tmp.y<miny)
				miny=tmp.y;
			if(tmp.y>maxy)
				maxy=tmp.y;
			
			linevec.push_back(line(last,tmp));
			last=tmp;
			
		}
		
		linevec.push_back(line(start,last));
		
		sort(linevec.begin(),linevec.end());
		unique(linevec.begin(),linevec.end());
		
		//nacteno*
		
		//testujeme, ktere ctverce jsou neintersekcni
		vector<point2i> nonintBoxes;
		
		for(int x=minx;x<maxx;x++){
			for(int y=maxy;y>miny;y--){
				point2i p;
				p.x=x;
				p.y=y;
				if (isNonIntersecting(p,linevec)){
					nonintBoxes.push_back(p);
				}
			}
		}
// 		cout << nonintBoxes.size() << " ";
// 		if (nonintBoxes.size()==7){
// 			for (int i=0;i<7;i++){
// 				cout << nonintBoxes[i].x << "," << nonintBoxes[i].y << " ";
// 			}
// 		}
		//mame pouze neintersekcni boxy, otestujeme ktere jsou uvnitr
		int counter=0;
		for(vector<point2i>::iterator it=nonintBoxes.begin();it!=nonintBoxes.end();it++){
			point lineStart(minx-1,(*it).y-0.5);
			point lineEnd((*it).x+0.5,(*it).y-0.5);
			line horLine(lineStart,lineEnd);
			//if (nonintBoxes.size()==7)cout << getTotalIntersections(horLine,linevec) << " ";
			if(getTotalIntersections(horLine,linevec)%2 == 1)
				counter++;
		}
		cout << counter << endl;
	}
}